@@ -1,16 +1,17 @@
-from __future__ import print_function, unicode_literals
+from __future__ import annotations
 
 import pytest
 
 
 @pytest.fixture(params=[None, 'inprocess', 'subprocess', 'both'])
-def launch_mode_conf(request):
+def launch_mode_conf(request: pytest.FixtureRequest) -> str | None:
     """Configured launch mode (None|'inprocess'|'subprocess'|'both')."""
+    assert request.param is None or isinstance(request.param, str)
     return request.param
 
 
 @pytest.fixture
-def launch_modes(launch_mode_conf):
+def launch_modes(launch_mode_conf: str | None) -> set[str]:
     """Set of launch modes in which the tests will actually be run.
 
     The value of this fixture depends on the value of `launch_mode_conf`:
@@ -26,19 +27,32 @@ def launch_modes(launch_mode_conf):
     return {'inprocess'}
 
 
-@pytest.fixture
-def run_test(testdir):
-    def run(script, passed=1, skipped=0, failed=0, launch_mode_conf=None):
-        testdir.makepyfile(script)
+class RunTest:
+    def __init__(self, testdir: pytest.Testdir) -> None:
+        self.testdir = testdir
+
+    def __call__(
+        self,
+        script: str,
+        passed: int = 1,
+        skipped: int = 0,
+        failed: int = 0,
+        launch_mode_conf: str | None = None
+    ) -> pytest.RunResult:
+        self.testdir.makepyfile(script)
         args = []
         if launch_mode_conf is not None:
             args.append('--script-launch-mode=' + launch_mode_conf)
-        result = testdir.runpytest(*args)
+        result = self.testdir.runpytest(*args)
         print('\n'.join(['pytest stdout:'] + result.outlines +
                         ['pytest stderr:'] + result.errlines))
         result.assert_outcomes(passed=passed, skipped=skipped, failed=failed)
         return result
-    return run
+
+
+@pytest.fixture
+def run_test(testdir: pytest.Testdir) -> RunTest:
+    return RunTest(testdir)
 
 
 CHECK_LAUNCH_MODE = """
@@ -49,7 +63,9 @@ def test_both(script_runner, accumulator=set()):
 """
 
 
-def test_command_line_option(run_test, launch_mode_conf, launch_modes):
+def test_command_line_option(
+    run_test: RunTest, launch_mode_conf: str | None, launch_modes: set[str]
+) -> None:
     run_test(
         CHECK_LAUNCH_MODE.format(launch_modes),
         passed=len(launch_modes),
@@ -57,12 +73,17 @@ def test_command_line_option(run_test, launch_mode_conf, launch_modes):
     )
 
 
-def test_config_option(run_test, testdir, launch_mode_conf, launch_modes):
+def test_config_option(
+    run_test: RunTest,
+    testdir: pytest.Testdir,
+    launch_mode_conf: str | None,
+    launch_modes: set[str],
+) -> None:
     if launch_mode_conf is not None:
-        testdir.makeini("""
+        testdir.makeini(f"""
             [pytest]
-            script_launch_mode = {}
-        """.format(launch_mode_conf))
+            script_launch_mode = {launch_mode_conf}
+        """)
 
     run_test(
         CHECK_LAUNCH_MODE.format(launch_modes),
@@ -70,7 +91,9 @@ def test_config_option(run_test, testdir, launch_mode_conf, launch_modes):
     )
 
 
-def test_override_launch_mode_with_mark(run_test, launch_mode_conf):
+def test_override_launch_mode_with_mark(
+    run_test: RunTest, launch_mode_conf: str | None
+) -> None:
     run_test(
         """
 import pytest
@@ -93,7 +116,7 @@ def test_both(script_runner, accumulator=set()):
     )
 
 
-def test_help_message(testdir):
+def test_help_message(testdir: pytest.Testdir) -> None:
     result = testdir.runpytest(
         '--help',
     )
